#
# spec file for package ghc-sop-core
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name sop-core
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        0.5.0.2
Release:        7.1
Summary:        True Sums of Products
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/5.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}

%description
Implementation of n-ary sums and n-ary products.

The module "Data.SOP" is the main module of this library and contains more
detailed documentation.

The main use case of this package is to serve as the core of
'<https://hackage.haskell.org/package/generics-sop generics-sop>'.

A detailed description of the ideas behind this library is provided by the
paper:

* Edsko de Vries and Andres Löh.
<http://www.andres-loeh.de/TrueSumsOfProducts True Sums of Products>.
Workshop on Generic Programming (WGP) 2014.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md doctest.sh

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sat Jan  4 2025 Peter Simons <psimons@suse.com>
- Update sop-core to version 0.5.0.2 revision 5.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon May 13 2024 Peter Simons <psimons@suse.com>
- Update sop-core to version 0.5.0.2 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Oct 18 2023 Peter Simons <psimons@suse.com>
- Update sop-core to version 0.5.0.2 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Apr 12 2023 Peter Simons <psimons@suse.com>
- Update sop-core to version 0.5.0.2 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Aug 22 2022 Peter Simons <psimons@suse.com>
- Update sop-core to version 0.5.0.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Jan  2 2022 Peter Simons <psimons@suse.com>
- Update sop-core to version 0.5.0.2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/sop-core-0.5.0.2/src/CHANGELOG.md
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Nov  3 2020 psimons@suse.com
- Add sop-core at version 0.5.0.1 revision 1.
